PySkein 0.6.2 — PySkein v0.6.2 documentation

### Navigation

- index
- next |
- PySkein v0.6.2 documentation »

# PySkein 0.6.2

PySkein is an extension module for Python 3.0 or later, implementing the Skein hash algorithm, one of the Second Round Candidates in the NIST SHA-3 Competition. While originally based on the optimized version of the reference implementation by Doug Whiting, PySkein has since evolved into a feature-rich and pythonic module. It is released as free software under the GNU General Public License. Its highlights are:

- A simple interface following the hash algorithms in the Python standard library (like hashlib.sha1 or hashlib.sha256)
- Many features of the Skein specification (such as tree hashing, various parameters and output sizes etc.)
- High hashing performance through efficient implementation in C (370 MB/s in sequential hashing and 579 MB/s in tree hashing on two cores, measured on a 2.8 GHz Opteron)
- Threefish, the tweakable block cipher used in Skein, available for encrytion and decryption on its own

Table of Contents:

- Skein hash
  - Hash objects
  - Simple examples
  - Advanced examples
- Threefish block cipher
  - Threefish objects
  - Examples
- Pseudorandom Number Generator
- Demo Scripts
  - skeinsum
  - threefish
- Download PySkein
  - Changes between version
  - Previous versions

### Navigation

- index
- next |
- PySkein v0.6.2 documentation »